summaryrefslogtreecommitdiff
path: root/TAO/tao
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2000-06-26 19:47:57 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2000-06-26 19:47:57 +0000
commit7a10139780f7eba35526a2ea7f82c02014a74c5d (patch)
treecc96bd89b85fb31a9520732c442def9760a089e0 /TAO/tao
parent650722067a96af124d9c36d19a9f5d3bc5eaa1d3 (diff)
downloadATCD-7a10139780f7eba35526a2ea7f82c02014a74c5d.tar.gz
ChangeLogTag:Mon Jun 26 12:44:40 2000 Ossama Othman <ossama@uci.edu>
Diffstat (limited to 'TAO/tao')
-rw-r--r--TAO/tao/Acceptor_Registry.cpp319
-rw-r--r--TAO/tao/Acceptor_Registry.h25
-rw-r--r--TAO/tao/IIOP_Acceptor.cpp42
-rw-r--r--TAO/tao/IIOP_Acceptor.h12
-rw-r--r--TAO/tao/Makefile575
-rw-r--r--TAO/tao/POA.cpp1
-rw-r--r--TAO/tao/Pluggable.cpp13
-rw-r--r--TAO/tao/Pluggable.h11
-rw-r--r--TAO/tao/SHMIOP_Acceptor.cpp20
-rw-r--r--TAO/tao/SHMIOP_Acceptor.h4
-rw-r--r--TAO/tao/UIOP_Acceptor.cpp22
-rw-r--r--TAO/tao/UIOP_Acceptor.h4
12 files changed, 407 insertions, 641 deletions
diff --git a/TAO/tao/Acceptor_Registry.cpp b/TAO/tao/Acceptor_Registry.cpp
index c00dd7c0ba7..5c592a0ce40 100644
--- a/TAO/tao/Acceptor_Registry.cpp
+++ b/TAO/tao/Acceptor_Registry.cpp
@@ -145,8 +145,6 @@ TAO_Acceptor_Registry::open (TAO_ORB_Core *orb_core,
ACE_CHECK_RETURN (-1);
}
- ACE_Auto_Basic_Array_Ptr <char> addr_str;
-
for (ACE_CString *endpoint = 0;
endpoints.next (endpoint) != 0;
endpoints.advance ())
@@ -166,10 +164,10 @@ TAO_Acceptor_Registry::open (TAO_ORB_Core *orb_core,
iop.c_str ()));
ACE_THROW_RETURN (CORBA::BAD_PARAM (
- CORBA_SystemException::_tao_minor_code (
- TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
- EINVAL),
- CORBA::COMPLETED_NO),
+ CORBA_SystemException::_tao_minor_code (
+ TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
+ EINVAL),
+ CORBA::COMPLETED_NO),
-1);
}
@@ -193,124 +191,22 @@ TAO_Acceptor_Registry::open (TAO_ORB_Core *orb_core,
factory != end;
++factory)
{
+
if ((*factory)->factory ()->match_prefix (prefix))
{
- found = 1; // A usable protocol was found.
-
// increment slot past the "://" (i.e. add 3)
ACE_CString addrs = iop.substring (slot + 3);
- ACE_CString options;
-
- int options_index =
- addrs.find ((*factory)->factory ()->options_delimiter ());
-
- if (options_index == ACE_static_cast (int,
- addrs.length () - 1))
- {
- // Get rid of trailing option delimiter.
- addrs = addrs.substring (0, addrs.length () - 1);
- }
- else if (options_index != ACE_CString::npos)
- {
- options = addrs.substring (options_index + 1);
-
- addrs = addrs.substring (0, options_index);
- }
-
- // Check for the presence of addresses.
- if (addrs.length () == 0)
- {
- // Protocol was specified without an endpoint.
- // All TAO pluggable protocols are expected to have
- // the ability to create a default endpoint.
- if (this->open_default (orb_core,
- factory,
- ((options.length () == 0)
- ? 0 : options.c_str ())) == 0)
- continue;
- else
- ACE_THROW_RETURN (CORBA::INTERNAL (
- CORBA_SystemException::_tao_minor_code (
- TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
- 0),
- CORBA::COMPLETED_NO),
- -1);
- }
-
- char *last_addr = 0;
- addr_str.reset (addrs.rep ());
-
- // Iterate over the addrs specified in the endpoint.
- for (char *astr = ACE_OS::strtok_r (addr_str.get (),
- ",",
- &last_addr);
- astr != 0 ;
- astr = ACE_OS::strtok_r (0,
- ",",
- &last_addr))
- {
- ACE_CString address (astr);
-
- TAO_Acceptor *acceptor =
- (*factory)->factory ()->make_acceptor ();
- if (acceptor != 0)
- {
- // Check if an "N.n@" version prefix was
- // specified.
- int major = -1;
- int minor = -1;
- if (isdigit (address[0])
- && address[1] == '.'
- && isdigit (address[2])
- && address[3] == '@')
- {
- major = address[0] - '0';
- minor = address[2] - '0';
- address = address.substring (4);
- }
-
- if (acceptor->open (orb_core,
- major, minor,
- address.c_str (),
- ((options.length () == 0)
- ? 0 : options.c_str ())) == -1)
- {
- delete acceptor;
-
- if (TAO_debug_level > 0)
- ACE_ERROR ((LM_ERROR,
- ACE_TEXT ("TAO (%P|%t) unable to open acceptor ")
- ACE_TEXT ("for <%s>%p\n"),
- iop.c_str (),""));
-
- ACE_THROW_RETURN (CORBA::BAD_PARAM (
- CORBA_SystemException::_tao_minor_code (
- TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
- EINVAL),
- CORBA::COMPLETED_NO),
- -1);
- }
-
- // add acceptor to list
- this->acceptors_[this->size_++] = acceptor;
- }
- else
- {
- if (TAO_debug_level > 0)
- ACE_ERROR ((LM_ERROR,
- ACE_TEXT ("TAO (%P|%t) unable to create ")
- ACE_TEXT ("an acceptor for <%s>.\n"),
- iop.c_str ()));
-
- ACE_THROW_RETURN (CORBA::NO_MEMORY (
- CORBA_SystemException::_tao_minor_code (
- TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
- ENOMEM),
- CORBA::COMPLETED_NO),
- -1);
- }
- }
+ int result = this->open_i (orb_core,
+ addrs,
+ factory,
+ ACE_TRY_ENV);
+ ACE_CHECK_RETURN (-1);
+
+ if (result != 0)
+ return -1;
+
+ found = 1; // A usable protocol was found.
}
else
continue;
@@ -319,14 +215,15 @@ TAO_Acceptor_Registry::open (TAO_ORB_Core *orb_core,
if (found == 0)
{
ACE_ERROR ((LM_ERROR,
- ACE_TEXT ("TAO (%P|%t) no usable transport protocol ")
+ ACE_TEXT ("TAO (%P|%t) ")
+ ACE_TEXT ("no usable transport protocol ")
ACE_TEXT ("was found.\n")));
ACE_THROW_RETURN (CORBA::BAD_PARAM (
- CORBA_SystemException::_tao_minor_code (
- TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
- EINVAL),
- CORBA::COMPLETED_NO),
+ CORBA_SystemException::_tao_minor_code (
+ TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
+ EINVAL),
+ CORBA::COMPLETED_NO),
-1);
}
}
@@ -368,7 +265,11 @@ int TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
// up if the server crashes.
if (!(*i)->factory ()->requires_explicit_endpoint ())
{
- if (this->open_default (orb_core, i, options) != 0)
+ if (this->open_default (orb_core,
+ -1, /* use default major version */
+ -1, /* use default minor version */
+ i,
+ options) != 0)
return -1;
opened_endpoint = 1;
@@ -396,6 +297,8 @@ int TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
// the indicated protocol.
int
TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
+ int major,
+ int minor,
TAO_ProtocolFactorySetItor &factory,
const char *options)
{
@@ -418,7 +321,10 @@ TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
}
// Initialize the acceptor to listen on a default endpoint.
- if (acceptor->open_default (orb_core, options) == -1)
+ if (acceptor->open_default (orb_core,
+ major,
+ minor,
+ options) == -1)
{
delete acceptor;
@@ -458,6 +364,167 @@ TAO_Acceptor_Registry::close_all (void)
return 0;
}
+void
+TAO_Acceptor_Registry::extract_endpoint_options (ACE_CString &addrs,
+ ACE_CString &options,
+ TAO_Protocol_Factory *factory)
+{
+ int options_index =
+ addrs.find (factory->options_delimiter ());
+
+ if (options_index == ACE_static_cast (int,
+ addrs.length () - 1))
+ {
+ // Get rid of trailing option delimiter.
+ addrs = addrs.substring (0, addrs.length () - 1);
+ }
+ else if (options_index != ACE_CString::npos)
+ {
+ options = addrs.substring (options_index + 1);
+
+ addrs = addrs.substring (0, options_index);
+ }
+}
+
+void
+TAO_Acceptor_Registry::extract_endpoint_version (ACE_CString &address,
+ int &major,
+ int &minor)
+{
+ // Check if an "N.n@" version prefix was
+ // specified.
+ major = -1;
+ minor = -1;
+ if (isdigit (address[0])
+ && address[1] == '.'
+ && isdigit (address[2])
+ && address[3] == '@')
+ {
+ major = address[0] - '0';
+ minor = address[2] - '0';
+ address = address.substring (4);
+ }
+}
+
+int
+TAO_Acceptor_Registry::open_i (TAO_ORB_Core *orb_core,
+ ACE_CString &addrs,
+ TAO_ProtocolFactorySetItor &factory,
+ CORBA::Environment &ACE_TRY_ENV)
+{
+ ACE_CString options_tmp;
+ this->extract_endpoint_options (addrs,
+ options_tmp,
+ (*factory)->factory ());
+
+ const char *options = 0;
+ if (options_tmp.length () > 0)
+ options = options_tmp.c_str ();
+
+ char *last_addr = 0;
+ ACE_Auto_Basic_Array_Ptr <char> addr_str (addrs.rep ());
+
+ char *astr = ACE_OS::strtok_r (addr_str.get (),
+ ",",
+ &last_addr);
+ if (astr == 0)
+ astr = "";
+
+ // Iterate over the addrs specified in the endpoint.
+
+ for ( ;
+ astr != 0 ;
+ astr = ACE_OS::strtok_r (0,
+ ",",
+ &last_addr))
+ {
+ ACE_CString address (astr);
+
+ TAO_Acceptor *acceptor =
+ (*factory)->factory ()->make_acceptor ();
+ if (acceptor != 0)
+ {
+ // Extract the desired endpoint/protocol version if one
+ // exists.
+ int major = -1;
+ int minor = -1;
+ this->extract_endpoint_version (address,
+ major,
+ minor);
+
+ // Check for existence of endpoint.
+ if (address.length () == 0)
+ {
+ // Protocol prefix was specified without any endpoints.
+ // All TAO pluggable protocols are expected to have the
+ // ability to create a default endpoint.
+ if (this->open_default (orb_core,
+ major,
+ minor,
+ factory,
+ options) == 0)
+ continue;
+
+ // Could not open a default endpoint, nor an explicit
+ // one.
+ else
+ ACE_THROW_RETURN (CORBA::INTERNAL (
+ CORBA_SystemException::_tao_minor_code (
+ TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
+ 0),
+ CORBA::COMPLETED_NO),
+ -1);
+ }
+
+ // An explicit endpoint was provided.
+ else if (acceptor->open (orb_core,
+ major,
+ minor,
+ address.c_str (),
+ options) == -1)
+ {
+ delete acceptor;
+
+ if (TAO_debug_level > 0)
+ ACE_ERROR ((LM_ERROR,
+ ACE_TEXT ("TAO (%P|%t) ")
+ ACE_TEXT ("unable to open acceptor ")
+ ACE_TEXT ("for <%s>%p\n"),
+ address.c_str (),
+ ""));
+
+ ACE_THROW_RETURN (CORBA::BAD_PARAM (
+ CORBA_SystemException::_tao_minor_code (
+ TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
+ EINVAL),
+ CORBA::COMPLETED_NO),
+ -1);
+ }
+
+ // add acceptor to list
+ this->acceptors_[this->size_++] = acceptor;
+ }
+ else
+ {
+ if (TAO_debug_level > 0)
+ ACE_ERROR ((LM_ERROR,
+ ACE_TEXT ("TAO (%P|%t) unable to create ")
+ ACE_TEXT ("an acceptor for <%s>.\n"),
+ address.c_str ()));
+
+ ACE_THROW_RETURN (CORBA::NO_MEMORY (
+ CORBA_SystemException::_tao_minor_code (
+ TAO_ACCEPTOR_REGISTRY_OPEN_LOCATION_CODE,
+ ENOMEM),
+ CORBA::COMPLETED_NO),
+ -1);
+ }
+ }
+
+ return 0;
+}
+
+
#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
diff --git a/TAO/tao/Acceptor_Registry.h b/TAO/tao/Acceptor_Registry.h
index 39d1afdd682..54b0ab58303 100644
--- a/TAO/tao/Acceptor_Registry.h
+++ b/TAO/tao/Acceptor_Registry.h
@@ -14,6 +14,7 @@
//
// = AUTHOR
// Fred Kuhns <fredk@cs.wustl.edu>
+// Ossama Othman <ossama@uci.edu>
//
// ============================================================================
@@ -27,6 +28,7 @@
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */
+#include "ace/SString.h"
#include "tao/corbafwd.h"
#include "tao/Resource_Factory.h"
@@ -83,21 +85,42 @@ public:
TAO_Acceptor *get_acceptor (CORBA::ULong tag);
// Return the acceptor bridges
-
+
// = Iterator.
TAO_AcceptorSetIterator begin (void);
TAO_AcceptorSetIterator end (void);
private:
+
int open_default (TAO_ORB_Core *orb_core,
const char *options);
// Create a default acceptor for all loaded protocols.
int open_default (TAO_ORB_Core *orb_core,
+ int major,
+ int minor,
TAO_ProtocolFactorySetItor &factory,
const char *options);
// Create a default acceptor using the specified protocol factory.
+ void extract_endpoint_options (ACE_CString &addrs,
+ ACE_CString &options,
+ TAO_Protocol_Factory *factory);
+ // Extract endpoint-specific options from the endpoint string.
+
+ void extract_endpoint_version (ACE_CString &address,
+ int &major,
+ int &minor);
+ // Extract endpoint/address specific version from the endpoint
+ // string.
+
+ int open_i (TAO_ORB_Core *orb_core,
+ ACE_CString &address,
+ TAO_ProtocolFactorySetItor &factory,
+ CORBA::Environment &ACE_TRY_ENV);
+ // Iterator through addrs in the string <iop>, and create an
+ // acceptor for each one.
+
private:
// The acceptor registry should not be copied.
ACE_UNIMPLEMENTED_FUNC (TAO_Acceptor_Registry (const TAO_Acceptor_Registry&))
diff --git a/TAO/tao/IIOP_Acceptor.h b/TAO/tao/IIOP_Acceptor.h
index bc2f993adfb..38493cb34dd 100644
--- a/TAO/tao/IIOP_Acceptor.h
+++ b/TAO/tao/IIOP_Acceptor.h
@@ -14,7 +14,8 @@
// IIOP specific acceptor processing
//
// = AUTHOR
-// Fred Kuhns
+// Fred Kuhns <fredk@cs.wustl.edu>
+// Ossama Othman <ossama@uci.edu>
//
//============================================================================
@@ -68,6 +69,8 @@ public:
const char *address,
const char *options = 0);
virtual int open_default (TAO_ORB_Core *orb_core,
+ int version_major,
+ int version_minor,
const char *options = 0);
virtual int close (void);
virtual int create_mprofile (const TAO_ObjectKey &object_key,
@@ -107,8 +110,9 @@ protected:
// example, if the IP address is INADDR_ANY (0.0.0.0) then there
// will be possibly a different hostname for each interface.
- size_t num_hosts_;
- // The number of host names cached in the hosts_ array.
+ size_t endpoint_count_;
+ // The number of host names cached in the hosts_ array (equivalent
+ // to the number of endpoints opened by this Acceptor).
TAO_GIOP_Version version_;
// The GIOP version for this endpoint
@@ -124,7 +128,7 @@ private:
TAO_IIOP_CONCURRENCY_STRATEGY *concurrency_strategy_;
TAO_IIOP_ACCEPT_STRATEGY *accept_strategy_;
// Acceptor strategies.
-
+
CORBA::Boolean lite_flag_;
// Should we use GIOP lite??
diff --git a/TAO/tao/Makefile b/TAO/tao/Makefile
index e13e333299a..8d5ca6bb844 100644
--- a/TAO/tao/Makefile
+++ b/TAO/tao/Makefile
@@ -602,24 +602,21 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- POA.h \
- Object_KeyC.h \
- Object_KeyC.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
IOPC.h \
IOPC.i \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ POA.h \
+ Object_KeyC.h \
+ Object_KeyC.i \
+ POAManager.h \
+ POAManager.i \
POA.i \
ORB.h \
IOR_LookupTable.h \
@@ -1004,23 +1001,20 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- Object_KeyC.h \
- Object_KeyC.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
IOPC.h \
IOPC.i \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ Object_KeyC.h \
+ Object_KeyC.i \
+ POAManager.h \
+ POAManager.i \
POA.i \
ORB_Core.h \
ORB.h \
@@ -1104,8 +1098,6 @@ realclean:
ImplRepoS_T.i \
ImplRepoS_T.cpp \
ImplRepoS.i \
- Acceptor_Registry.h \
- Acceptor_Registry.i \
Forwarding_Servant.h
.obj/POAC.o .obj/POAC.so .shobj/POAC.o .shobj/POAC.so: POAC.cpp \
@@ -1231,9 +1223,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
POA.h \
$(ACE_ROOT)/ace/Hash_Map_Manager.h \
@@ -1284,17 +1273,17 @@ realclean:
poa_macros.h \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- Object_KeyC.h \
- Object_KeyC.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
IOPC.h \
IOPC.i \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ Object_KeyC.h \
+ Object_KeyC.i \
+ POAManager.h \
+ POAManager.i \
POA.i \
Invocation.h \
ORB_Core.h \
@@ -1495,9 +1484,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
Server_Request.h \
IOPC.h \
@@ -1706,9 +1692,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
poa_macros.h \
POAManager.i \
@@ -1760,15 +1743,15 @@ realclean:
Server_Strategy_Factory.h \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- Object_KeyC.h \
- Object_KeyC.i \
RTCORBAC.h \
IOPC.h \
IOPC.i \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ Object_KeyC.h \
+ Object_KeyC.i \
POA.i
.obj/Active_Object_Map.o .obj/Active_Object_Map.so .shobj/Active_Object_Map.o .shobj/Active_Object_Map.so: Active_Object_Map.cpp \
@@ -2102,9 +2085,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -2162,15 +2142,15 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ TimeBaseC.h \
+ TimeBaseC.i \
+ RTCORBAC.i \
Object_Adapter.i \
Object_KeyC.h \
Object_KeyC.i \
POAManager.h \
POAManager.i \
- RTCORBAC.h \
- TimeBaseC.h \
- TimeBaseC.i \
- RTCORBAC.i \
POA.i \
Stub.h \
MProfile.h \
@@ -2456,8 +2436,7 @@ realclean:
Any.h \
Typecode.h \
Typecode.i \
- Any.i \
- ImplRepoC.i \
+ Any.i ImplRepoC.i \
Stub.h \
Pluggable.h \
$(ACE_ROOT)/ace/Message_Queue.h \
@@ -2550,9 +2529,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -2588,8 +2564,7 @@ realclean:
Invocation.i
.obj/ImplRepoS.o .obj/ImplRepoS.so .shobj/ImplRepoS.o .shobj/ImplRepoS.so: ImplRepoS.cpp ImplRepoS.h \
- $(ACE_ROOT)/ace/pre.h \
- ImplRepoC.h \
+ $(ACE_ROOT)/ace/pre.h ImplRepoC.h \
Object.h \
corbafwd.h \
$(ACE_ROOT)/ace/CDR_Stream.h \
@@ -2695,8 +2670,7 @@ realclean:
Any.h \
Typecode.h \
Typecode.i \
- Any.i \
- ImplRepoC.i \
+ Any.i ImplRepoC.i \
POAC.h \
PolicyC.h \
CurrentC.h \
@@ -2766,12 +2740,13 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ TimeBaseC.h \
+ TimeBaseC.i \
+ RTCORBAC.i \
Object_Adapter.i \
Stub.h \
Pluggable.h \
@@ -3001,7 +2976,6 @@ realclean:
CDR.i \
IOPC.i \
Pluggable.i \
- Stub.h \
MProfile.h \
Profile.h \
Tagged_Components.h \
@@ -3019,6 +2993,7 @@ realclean:
PolicyC.i \
Profile.i \
MProfile.i \
+ ORB_Core.h \
ORB.h \
IOR_LookupTable.h \
Services.h \
@@ -3037,8 +3012,6 @@ realclean:
InterceptorC.i \
Interceptor.i \
ORB.i \
- Stub.i \
- ORB_Core.h \
Policy_Manager.h \
POA_CORBA.h \
DynAnyC.h \
@@ -3047,9 +3020,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -3064,8 +3034,6 @@ realclean:
Client_Strategy_Factory.h \
Wait_Strategy.h \
Transport_Mux_Strategy.h \
- Reply_Dispatcher.h \
- Reply_Dispatcher.i \
debug.h \
target_specification.h \
Object_KeyC.h \
@@ -3462,9 +3430,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -3707,9 +3672,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
params.h \
params.i \
@@ -4125,9 +4087,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
params.h \
@@ -4411,9 +4370,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
params.h \
@@ -4701,9 +4657,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -4738,13 +4691,13 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ POAManager.h \
+ POAManager.i \
POA.i \
debug.h
@@ -5006,9 +4959,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -5305,9 +5255,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
params.h \
params.i \
@@ -5560,9 +5507,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -5833,9 +5777,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -6120,9 +6061,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
params.h \
@@ -6408,9 +6346,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
params.h \
@@ -6700,9 +6635,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -6737,13 +6669,13 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ POAManager.h \
+ POAManager.i \
POA.i \
debug.h
@@ -7008,9 +6940,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -7312,9 +7241,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
params.h \
params.i \
@@ -7567,9 +7493,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -7837,9 +7760,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -8131,9 +8051,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
params.h \
@@ -8427,9 +8344,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -8464,13 +8378,13 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ POAManager.h \
+ POAManager.i \
POA.i \
debug.h
@@ -8738,9 +8652,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -9045,9 +8956,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
params.h \
params.i \
@@ -9304,9 +9212,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -9580,9 +9485,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -9824,9 +9726,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -10339,9 +10238,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -10558,9 +10454,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -10790,9 +10683,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
params.h \
params.i \
@@ -12139,9 +12029,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -12373,10 +12260,7 @@ realclean:
DynAnyC.h \
DynAnyC.i \
DomainC.h \
- DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i
+ DomainC.i
.obj/CurrentS.o .obj/CurrentS.so .shobj/CurrentS.o .shobj/CurrentS.so: CurrentS.cpp \
CurrentC.h \
@@ -12526,9 +12410,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Server_Request.h \
IOPC.h \
IOPC.i \
@@ -12900,9 +12781,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -13107,12 +12985,15 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ IOPC.h \
+ IOPC.i \
+ TimeBaseC.h \
+ TimeBaseC.i \
+ RTCORBAC.i \
Object_Adapter.i \
Stub.h \
Pluggable.h \
@@ -13137,8 +13018,6 @@ realclean:
$(ACE_ROOT)/ace/WFMO_Reactor.i \
$(ACE_ROOT)/ace/Strategies.i \
$(ACE_ROOT)/ace/Message_Queue.i \
- IOPC.h \
- IOPC.i \
Pluggable.i \
MProfile.h \
Profile.h \
@@ -13173,8 +13052,6 @@ realclean:
ValueBase.i \
ValueFactory.h \
ValueFactory.i \
- TimeBaseC.h \
- TimeBaseC.i \
PollableC.h \
PollableC.i \
MessagingC.i \
@@ -13384,12 +13261,15 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ IOPC.h \
+ IOPC.i \
+ TimeBaseC.h \
+ TimeBaseC.i \
+ RTCORBAC.i \
Object_Adapter.i \
Stub.h \
Pluggable.h \
@@ -13414,8 +13294,6 @@ realclean:
$(ACE_ROOT)/ace/WFMO_Reactor.i \
$(ACE_ROOT)/ace/Strategies.i \
$(ACE_ROOT)/ace/Message_Queue.i \
- IOPC.h \
- IOPC.i \
Pluggable.i \
MProfile.h \
Profile.h \
@@ -13450,8 +13328,6 @@ realclean:
ValueBase.i \
ValueFactory.h \
ValueFactory.i \
- TimeBaseC.h \
- TimeBaseC.i \
PollableC.h \
PollableC.i \
MessagingC.i \
@@ -13889,9 +13765,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
ORB_Core.h \
Policy_Manager.h \
Policy_Manager.i \
@@ -13923,16 +13796,16 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ TimeBaseC.h \
+ TimeBaseC.i \
+ RTCORBAC.i \
Object_Adapter.i \
POA.h \
Object_KeyC.h \
Object_KeyC.i \
POAManager.h \
POAManager.i \
- RTCORBAC.h \
- TimeBaseC.h \
- TimeBaseC.i \
- RTCORBAC.i \
POA.i \
Request.h \
Context.h \
@@ -14245,9 +14118,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Invocation.h \
ORB_Core.h \
Policy_Manager.h \
@@ -14438,9 +14308,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
ORB.h \
IOR_LookupTable.h \
Services.h \
@@ -14885,9 +14752,6 @@ realclean:
POA_CORBA.h \
DynAnyC.h \
DynAnyC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -15075,9 +14939,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
ORB.h \
IOR_LookupTable.h \
Services.h \
@@ -15682,9 +15543,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -16093,9 +15951,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -16510,9 +16365,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -16968,9 +16820,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -17461,9 +17310,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -17538,6 +17384,25 @@ realclean:
Connector_Registry.i \
Wait_Strategy.h \
Transport_Mux_Strategy.h \
+ RT_Policy_i.h \
+ RTCORBAS.h \
+ IOPS.h \
+ IOPS_T.h \
+ IOPS_T.i \
+ IOPS_T.cpp \
+ IOPS.i \
+ TimeBaseS.h \
+ TimeBaseS_T.h \
+ TimeBaseS_T.i \
+ TimeBaseS_T.cpp \
+ TimeBaseS.i \
+ RTCORBAC.h \
+ RTCORBAC.i \
+ RTCORBAS_T.h \
+ RTCORBAS_T.i \
+ RTCORBAS_T.cpp \
+ RTCORBAS.i \
+ RT_Policy_i.i \
Messaging_Policy_i.h \
MessagingC.h \
ValueBase.h \
@@ -17720,9 +17585,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -17970,9 +17832,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -18645,9 +18504,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -18739,15 +18595,15 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ TimeBaseC.h \
+ TimeBaseC.i \
+ RTCORBAC.i \
Object_Adapter.i \
Object_KeyC.h \
Object_KeyC.i \
POAManager.h \
POAManager.i \
- RTCORBAC.h \
- TimeBaseC.h \
- TimeBaseC.i \
- RTCORBAC.i \
POA.i \
Priority_Mapping.h \
Priority_Mapping.i \
@@ -18922,9 +18778,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -19222,9 +19075,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -19434,9 +19284,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -19785,9 +19632,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
params.h \
params.i \
@@ -20098,9 +19942,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -21175,9 +21016,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -21380,9 +21218,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -22108,9 +21943,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -22332,9 +22164,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -22893,8 +22722,7 @@ realclean:
Exception.h \
Exception.i \
CDR.h \
- CDR.i \
- PollableC.i \
+ CDR.i PollableC.i \
POA_CORBA.h \
CurrentC.h \
Environment.h \
@@ -22922,9 +22750,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Stub.h \
Pluggable.h \
$(ACE_ROOT)/ace/Message_Queue.h \
@@ -23129,8 +22954,8 @@ realclean:
Exception.h \
Exception.i \
CDR.h \
- CDR.i \
- PollableC.i PollableS_T.h PollableS_T.i PollableS_T.cpp PollableS.i
+ CDR.i PollableC.i \
+ PollableS_T.h PollableS_T.i PollableS_T.cpp PollableS.i
.obj/CONV_FRAMEC.o .obj/CONV_FRAMEC.so .shobj/CONV_FRAMEC.o .shobj/CONV_FRAMEC.so: CONV_FRAMEC.cpp \
CONV_FRAMEC.h \
@@ -23788,8 +23613,7 @@ realclean:
Typecode.i \
Any.i \
TimeBaseC.i \
- TAOC.i \
- TAOS.h \
+ TAOC.i TAOS.h \
TAOS_T.h \
TAOS_T.i \
TAOS_T.cpp \
@@ -24874,9 +24698,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -24930,8 +24751,8 @@ realclean:
$(ACE_ROOT)/ace/Basic_Types.h \
$(ACE_ROOT)/ace/Basic_Types.i \
$(ACE_ROOT)/ace/Trace.h \
- $(ACE_ROOT)/ace/OS.i \
- MessagingS.h orbconf.h TimeBaseS.h \
+ $(ACE_ROOT)/ace/OS.i MessagingS.h \
+ orbconf.h TimeBaseS.h \
TimeBaseC.h \
Any.h \
CDR.h \
@@ -25120,17 +24941,13 @@ realclean:
InterceptorC.i \
Interceptor.i \
ORB.i \
- Stub.i \
- ORB_Core.h \
+ Stub.i ORB_Core.h \
Policy_Manager.h \
POA_CORBA.h \
DynAnyC.h \
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -25164,6 +24981,8 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ RTCORBAC.i \
Object_Adapter.i
.obj/Policy_Manager.o .obj/Policy_Manager.so .shobj/Policy_Manager.o .shobj/Policy_Manager.so: Policy_Manager.cpp \
@@ -25289,9 +25108,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
ORB_Core.h \
ORB.h \
@@ -26370,9 +26186,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Protocol_Factory.h \
@@ -27000,9 +26813,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -27050,8 +26860,7 @@ realclean:
$(ACE_ROOT)/ace/Basic_Types.h \
$(ACE_ROOT)/ace/Basic_Types.i \
$(ACE_ROOT)/ace/Trace.h \
- $(ACE_ROOT)/ace/OS.i \
- corbafwd.h \
+ $(ACE_ROOT)/ace/OS.i corbafwd.h \
$(ACE_ROOT)/ace/CDR_Stream.h \
$(ACE_ROOT)/ace/Message_Block.h \
$(ACE_ROOT)/ace/ACE.h \
@@ -27116,8 +26925,7 @@ realclean:
try_macros.h \
$(ACE_ROOT)/ace/CORBA_macros.h \
varbase.h \
- corbafwd.i \
- IOPC.h \
+ corbafwd.i IOPC.h \
CDR.h \
corbafwd.h \
CDR.i \
@@ -27140,14 +26948,12 @@ realclean:
CurrentC.i \
Encodable.h \
PolicyC.i \
- TimeBaseC.h \
- Any.h \
+ TimeBaseC.h Any.h \
Typecode.h \
Typecode.i \
Any.i \
TimeBaseC.i \
- RTCORBAC.i \
- TAOS.h \
+ RTCORBAC.i TAOS.h \
TAOS_T.h \
TAOS_T.i \
TAOS_T.cpp \
@@ -27175,8 +26981,8 @@ realclean:
$(ACE_ROOT)/ace/Basic_Types.h \
$(ACE_ROOT)/ace/Basic_Types.i \
$(ACE_ROOT)/ace/Trace.h \
- $(ACE_ROOT)/ace/OS.i \
- RTCORBAS.h orbconf.h IOPS.h \
+ $(ACE_ROOT)/ace/OS.i RTCORBAS.h \
+ orbconf.h IOPS.h \
IOPC.h \
CDR.h \
corbafwd.h \
@@ -27479,10 +27285,7 @@ realclean:
Stub.i \
POA_CORBA.h \
DomainC.h \
- DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i
+ DomainC.i
.obj/DynAnyS.o .obj/DynAnyS.so .shobj/DynAnyS.o .shobj/DynAnyS.so: DynAnyS.cpp \
DynAnyC.h \
@@ -27605,10 +27408,7 @@ realclean:
Servant_Base.h \
POAC.h \
POAC.i \
- Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i
+ Servant_Base.i
.obj/DynAny_i.o .obj/DynAny_i.so .shobj/DynAny_i.o .shobj/DynAny_i.so: DynAny_i.cpp \
DynAny_i.h \
@@ -27733,9 +27533,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
DynStruct_i.h \
DynSequence_i.h \
DynEnum_i.h \
@@ -27871,9 +27668,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
DynArray_i.h \
InconsistentTypeCodeC.h \
Marshal.h \
@@ -28045,9 +27839,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
DynEnum_i.h \
InconsistentTypeCodeC.h
@@ -28174,9 +27965,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
DynSequence_i.h \
InconsistentTypeCodeC.h \
Marshal.h \
@@ -28348,9 +28136,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
DynStruct_i.h \
InconsistentTypeCodeC.h \
ORB.h \
@@ -28522,9 +28307,6 @@ realclean:
POAC.h \
POAC.i \
Servant_Base.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
DynUnion_i.h \
DynUnion_i_T.h \
DynUnion_i_T.cpp \
@@ -28839,134 +28621,7 @@ realclean:
Sequence.i \
Sequence_T.h \
Sequence_T.i \
- Sequence_T.cpp \
- InterfaceC.i \
- Stub.h \
- Pluggable.h \
- $(ACE_ROOT)/ace/Message_Queue.h \
- $(ACE_ROOT)/ace/IO_Cntl_Msg.h \
- $(ACE_ROOT)/ace/Message_Queue_T.h \
- $(ACE_ROOT)/ace/Message_Queue_T.i \
- $(ACE_ROOT)/ace/Message_Queue_T.cpp \
- $(ACE_ROOT)/ace/Strategies.h \
- $(ACE_ROOT)/ace/Strategies_T.h \
- $(ACE_ROOT)/ace/Service_Config.h \
- $(ACE_ROOT)/ace/Service_Object.h \
- $(ACE_ROOT)/ace/Shared_Object.h \
- $(ACE_ROOT)/ace/Shared_Object.i \
- $(ACE_ROOT)/ace/Service_Object.i \
- $(ACE_ROOT)/ace/Service_Config.i \
- $(ACE_ROOT)/ace/Reactor.h \
- $(ACE_ROOT)/ace/Handle_Set.h \
- $(ACE_ROOT)/ace/Handle_Set.i \
- $(ACE_ROOT)/ace/Timer_Queue.h \
- $(ACE_ROOT)/ace/Timer_Queue_T.h \
- $(ACE_ROOT)/ace/Timer_Queue_T.i \
- $(ACE_ROOT)/ace/Timer_Queue_T.cpp \
- $(ACE_ROOT)/ace/Reactor.i \
- $(ACE_ROOT)/ace/Reactor_Impl.h \
- $(ACE_ROOT)/ace/Svc_Conf_Tokens.h \
- $(ACE_ROOT)/ace/Synch_Options.h \
- $(ACE_ROOT)/ace/Synch_Options.i \
- $(ACE_ROOT)/ace/Thread_Manager.h \
- $(ACE_ROOT)/ace/Thread_Manager.i \
- $(ACE_ROOT)/ace/Hash_Map_Manager.h \
- $(ACE_ROOT)/ace/Functor.h \
- $(ACE_ROOT)/ace/Functor.i \
- $(ACE_ROOT)/ace/Functor_T.h \
- $(ACE_ROOT)/ace/Functor_T.i \
- $(ACE_ROOT)/ace/Functor_T.cpp \
- $(ACE_ROOT)/ace/Hash_Map_Manager_T.h \
- $(ACE_ROOT)/ace/Hash_Map_Manager_T.i \
- $(ACE_ROOT)/ace/Hash_Map_Manager_T.cpp \
- $(ACE_ROOT)/ace/Strategies_T.i \
- $(ACE_ROOT)/ace/Strategies_T.cpp \
- $(ACE_ROOT)/ace/Service_Repository.h \
- $(ACE_ROOT)/ace/Service_Types.h \
- $(ACE_ROOT)/ace/Service_Types.i \
- $(ACE_ROOT)/ace/Service_Repository.i \
- $(ACE_ROOT)/ace/WFMO_Reactor.h \
- $(ACE_ROOT)/ace/WFMO_Reactor.i \
- $(ACE_ROOT)/ace/Strategies.i \
- $(ACE_ROOT)/ace/Message_Queue.i \
- IOPC.h \
- IOPC.i \
- Pluggable.i \
- MProfile.h \
- Profile.h \
- Tagged_Components.h \
- CONV_FRAMEC.h \
- CONV_FRAMEC.i \
- Tagged_Components.i \
- PolicyC.h \
- CurrentC.h \
- CurrentC.i \
- Encodable.h \
- PolicyC.i \
- Profile.i \
- MProfile.i \
- ORB.h \
- IOR_LookupTable.h \
- Services.h \
- Services.i \
- IORManipulation.h \
- IORS.h \
- IORC.h \
- IORC.i \
- Servant_Base.h \
- POAC.h \
- POAC.i \
- Servant_Base.i \
- IORS.i \
- Interceptor.h \
- InterceptorC.h \
- InterceptorC.i \
- Interceptor.i \
- ORB.i \
- Stub.i \
- Invocation.h \
- ORB_Core.h \
- Policy_Manager.h \
- POA_CORBA.h \
- DynAnyC.h \
- DynAnyC.i \
- DomainC.h \
- DomainC.i \
- InterfaceC.h \
- Policy_Manager.i \
- Resource_Factory.h \
- Protocol_Factory.h \
- params.h \
- params.i \
- $(ACE_ROOT)/ace/Map_Manager.h \
- $(ACE_ROOT)/ace/Map_Manager.i \
- $(ACE_ROOT)/ace/Map_Manager.cpp \
- ORB_Core.i \
- $(ACE_ROOT)/ace/Dynamic_Service.h \
- $(ACE_ROOT)/ace/Dynamic_Service.cpp \
- Synch_Reply_Dispatcher.h \
- Reply_Dispatcher.h \
- Reply_Dispatcher.i \
- GIOP_Message_State.h \
- Pluggable_Messaging.h \
- Pluggable_Messaging_Utils.h \
- Pluggable_Messaging_Utils.i \
- Pluggable_Messaging.i \
- GIOP_Message_State.i \
- Synch_Reply_Dispatcher.i \
- TAOC.h \
- TimeBaseC.h \
- TimeBaseC.i \
- TAOC.i \
- operation_details.h \
- target_specification.h \
- Object_KeyC.h \
- Object_KeyC.i \
- target_specification.i \
- operation_details.i \
- Invocation.i \
- NVList.h \
- NVList.i
+ Sequence_T.cpp
.obj/Pluggable_Messaging.o .obj/Pluggable_Messaging.so .shobj/Pluggable_Messaging.o .shobj/Pluggable_Messaging.so: Pluggable_Messaging.cpp \
Pluggable_Messaging.h \
@@ -29728,9 +29383,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -29789,13 +29441,13 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ POAManager.h \
+ POAManager.i \
POA.i \
debug.h \
GIOP_Utils.h \
@@ -30169,9 +29821,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -30608,9 +30257,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -30675,13 +30321,13 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
- Object_Adapter.i \
- POAManager.h \
- POAManager.i \
RTCORBAC.h \
TimeBaseC.h \
TimeBaseC.i \
RTCORBAC.i \
+ Object_Adapter.i \
+ POAManager.h \
+ POAManager.i \
POA.i
.obj/GIOP_Message_Lite.o .obj/GIOP_Message_Lite.so .shobj/GIOP_Message_Lite.o .shobj/GIOP_Message_Lite.so: GIOP_Message_Lite.cpp \
@@ -30858,9 +30504,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -30924,13 +30567,13 @@ realclean:
POAS.i \
Active_Object_Map.h \
Active_Object_Map.i \
+ RTCORBAC.h \
+ RTCORBAC.i \
Object_Adapter.i \
Object_KeyC.h \
Object_KeyC.i \
POAManager.h \
POAManager.i \
- RTCORBAC.h \
- RTCORBAC.i \
POA.i \
operation_details.h \
target_specification.h \
@@ -31124,9 +30767,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
@@ -31333,9 +30973,6 @@ realclean:
DynAnyC.i \
DomainC.h \
DomainC.i \
- InterfaceC.h \
- ifrfwd.h \
- InterfaceC.i \
Policy_Manager.i \
Resource_Factory.h \
Pluggable.h \
diff --git a/TAO/tao/POA.cpp b/TAO/tao/POA.cpp
index 73f66576f20..a94daaf83be 100644
--- a/TAO/tao/POA.cpp
+++ b/TAO/tao/POA.cpp
@@ -20,7 +20,6 @@
#if (TAO_HAS_MINIMUM_CORBA == 0)
# include "tao/ImplRepoC.h"
# include "tao/ImplRepoS.h"
-# include "tao/Acceptor_Registry.h"
#endif /* TAO_HAS_MINIMUM_CORBA */
diff --git a/TAO/tao/Pluggable.cpp b/TAO/tao/Pluggable.cpp
index 4b1d28c56c9..6ecc6b07172 100644
--- a/TAO/tao/Pluggable.cpp
+++ b/TAO/tao/Pluggable.cpp
@@ -2,16 +2,14 @@
// $Id$
#include "tao/Pluggable.h"
-#include "tao/Stub.h"
+#include "tao/MProfile.h"
#include "tao/Environment.h"
#include "tao/ORB_Core.h"
#include "tao/Client_Strategy_Factory.h"
#include "tao/Wait_Strategy.h"
#include "tao/Transport_Mux_Strategy.h"
-#include "tao/Reply_Dispatcher.h"
#include "tao/debug.h"
-#include "ace/ACE.h"
#include "tao/target_specification.h"
#if !defined (__ACE_INLINE__)
@@ -142,12 +140,14 @@ TAO_Transport::reset_message (ACE_Message_Block *message_block,
while (current_message_block != 0 &&
bytes_delivered != 0)
{
- size_t current_message_block_length = current_message_block->length ();
+ size_t current_message_block_length =
+ current_message_block->length ();
int completely_delivered_current_message_block =
bytes_delivered >= current_message_block_length;
- size_t adjustment_size = ACE_MIN (current_message_block_length, bytes_delivered);
+ size_t adjustment_size =
+ ACE_MIN (current_message_block_length, bytes_delivered);
// Reset according to send size.
current_message_block->rd_ptr (adjustment_size);
@@ -155,7 +155,8 @@ TAO_Transport::reset_message (ACE_Message_Block *message_block,
// If queued message, adjust the queue.
if (queued_message)
// Hand adjust <message_length>.
- this->buffering_queue_->message_length (this->buffering_queue_->message_length () - adjustment_size);
+ this->buffering_queue_->message_length (
+ this->buffering_queue_->message_length () - adjustment_size);
// Adjust <bytes_delivered>.
bytes_delivered -= adjustment_size;
diff --git a/TAO/tao/Pluggable.h b/TAO/tao/Pluggable.h
index feac0efb969..8fd7f1d0de0 100644
--- a/TAO/tao/Pluggable.h
+++ b/TAO/tao/Pluggable.h
@@ -285,9 +285,16 @@ public:
const char *options = 0) = 0;
// Method to initialize acceptor for address.
- virtual int open_default (TAO_ORB_Core *orb_core,
+ virtual int open_default (TAO_ORB_Core *,
+ int version_major,
+ int version_minor,
const char *options = 0) = 0;
- // Open an acceptor on the default endpoint for this protocol
+ // Open an acceptor with the given protocol version on a default
+ // endpoint
+ // @@ This method should be pure virtual, but in order to maintain
+ // some form of backward compatibilty, a default implementation
+ // is provided. Ideally, that default implementation should be
+ // removed in the near future.
virtual int close (void) = 0;
// Closes the acceptor
diff --git a/TAO/tao/SHMIOP_Acceptor.cpp b/TAO/tao/SHMIOP_Acceptor.cpp
index dc91873f702..74e51ad8efb 100644
--- a/TAO/tao/SHMIOP_Acceptor.cpp
+++ b/TAO/tao/SHMIOP_Acceptor.cpp
@@ -163,8 +163,16 @@ TAO_SHMIOP_Acceptor::open (TAO_ORB_Core *orb_core,
int
TAO_SHMIOP_Acceptor::open_default (TAO_ORB_Core *orb_core,
+ int major,
+ int minor,
const char *options)
{
+ if (major >=0 && minor >= 0)
+ this->version_.set_version (ACE_static_cast (CORBA::Octet,
+ major),
+ ACE_static_cast (CORBA::Octet,
+ minor));
+
// Parse options
if (this->parse_options (options) == -1)
return -1;
@@ -255,11 +263,11 @@ TAO_SHMIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
{
// Create the decoding stream from the encapsulation in the buffer,
TAO_InputCDR cdr (profile.profile_data.mb ());
-
+
CORBA::Octet major, minor;
-
+
// Read the version. We just read it here. We don't*do any*
- // processing.
+ // processing.
if (!(cdr.read_octet (major)
&& cdr.read_octet (minor)))
{
@@ -272,7 +280,7 @@ TAO_SHMIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
}
return -1;
}
-
+
CORBA::String_var host;
CORBA::UShort port = 0;
@@ -288,11 +296,11 @@ TAO_SHMIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
}
return -1;
}
-
+
// ... and object key.
if ((cdr >> object_key) == 0)
return -1;
-
+
// We are NOT bothered about the rest.
return 1;
diff --git a/TAO/tao/SHMIOP_Acceptor.h b/TAO/tao/SHMIOP_Acceptor.h
index 137c83e7888..3aff41db3a6 100644
--- a/TAO/tao/SHMIOP_Acceptor.h
+++ b/TAO/tao/SHMIOP_Acceptor.h
@@ -65,6 +65,8 @@ public:
const char *port,
const char *options = 0);
virtual int open_default (TAO_ORB_Core *orb_core,
+ int version_major,
+ int version_minor,
const char *options = 0);
virtual int close (void);
virtual int create_mprofile (const TAO_ObjectKey &object_key,
@@ -114,7 +116,7 @@ private:
off_t mmap_size_;
// Determine the minimum size of mmap file. This dictate the
// maximum size of a CORBA method invocation.
-
+
CORBA::Boolean lite_flag_;
// Should we use GIOP lite??
};
diff --git a/TAO/tao/UIOP_Acceptor.cpp b/TAO/tao/UIOP_Acceptor.cpp
index 64408b21c27..eb4277f1dbb 100644
--- a/TAO/tao/UIOP_Acceptor.cpp
+++ b/TAO/tao/UIOP_Acceptor.cpp
@@ -185,8 +185,16 @@ TAO_UIOP_Acceptor::open (TAO_ORB_Core *orb_core,
int
TAO_UIOP_Acceptor::open_default (TAO_ORB_Core *orb_core,
+ int major,
+ int minor,
const char *options)
{
+ if (major >=0 && minor >= 0)
+ this->version_.set_version (ACE_static_cast (CORBA::Octet,
+ major),
+ ACE_static_cast (CORBA::Octet,
+ minor));
+
// Parse options
if (this->parse_options (options) == -1)
return -1;
@@ -303,11 +311,11 @@ TAO_UIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
{
// Create the decoding stream from the encapsulation in the buffer,
TAO_InputCDR cdr (profile.profile_data.mb ());
-
+
CORBA::Octet major, minor;
-
+
// Read the version. We just read it here. We don't*do any*
- // processing.
+ // processing.
if (!(cdr.read_octet (major)
&& cdr.read_octet (minor)))
{
@@ -320,7 +328,7 @@ TAO_UIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
}
return -1;
}
-
+
char *rendezvous = 0;
// Get rendezvous_point
@@ -329,14 +337,14 @@ TAO_UIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
ACE_DEBUG ((LM_DEBUG, "error decoding UIOP rendezvous_point"));
return -1;
}
-
+
// delete the rendezvous point. We don't do any processing.
delete [] rendezvous;
-
+
// ... and object key.
if ((cdr >> object_key) == 0)
return -1;
-
+
return 1;
}
diff --git a/TAO/tao/UIOP_Acceptor.h b/TAO/tao/UIOP_Acceptor.h
index 3f5b0152819..3ee2b7a7243 100644
--- a/TAO/tao/UIOP_Acceptor.h
+++ b/TAO/tao/UIOP_Acceptor.h
@@ -68,6 +68,8 @@ public:
const char *address,
const char *options = 0);
virtual int open_default (TAO_ORB_Core *orb_core,
+ int version_major,
+ int version_minor,
const char *options = 0);
virtual int close (void);
virtual int create_mprofile (const TAO_ObjectKey &object_key,
@@ -107,7 +109,7 @@ private:
// Flag that determines whether or not the rendezvous point should
// be unlinked on close. This is really only used when an error
// occurs.
-
+
CORBA::Boolean lite_flag_;
// Should we use GIOP lite??
};
diff --git a/TAO/tao/IIOP_Acceptor.cpp b/TAO/tao/IIOP_Acceptor.cpp
index f491f9ceecb..6247d772363 100644
--- a/TAO/tao/IIOP_Acceptor.cpp
+++ b/TAO/tao/IIOP_Acceptor.cpp
@@ -46,7 +46,7 @@ TAO_IIOP_Acceptor::TAO_IIOP_Acceptor (CORBA::Boolean flag)
: TAO_Acceptor (TAO_TAG_IIOP_PROFILE),
addrs_ (0),
hosts_ (0),
- num_hosts_ (0),
+ endpoint_count_ (0),
version_ (TAO_DEF_GIOP_MAJOR, TAO_DEF_GIOP_MINOR),
orb_core_ (0),
base_acceptor_ (),
@@ -78,13 +78,13 @@ int
TAO_IIOP_Acceptor::create_mprofile (const TAO_ObjectKey &object_key,
TAO_MProfile &mprofile)
{
// Adding this->num_hosts_ to the TAO_MProfile.
int count = mprofile.profile_count ();
- if ((mprofile.size () - count) < this->num_hosts_
- && mprofile.grow (count + this->num_hosts_) == -1)
+ if ((mprofile.size () - count) < this->endpoint_count_
+ && mprofile.grow (count + this->endpoint_count_) == -1)
return -1;
- for (size_t i = 0; i < this->num_hosts_; ++i)
+ for (size_t i = 0; i < this->endpoint_count_; ++i)
{
TAO_IIOP_Profile *pfile = 0;
ACE_NEW_RETURN (pfile,
@@ -132,7 +132,7 @@ TAO_IIOP_Acceptor::is_collocated (const TAO_Profile *pfile)
if (profile == 0)
return 0;
- for (size_t i = 0; i < this->num_hosts_; ++i)
+ for (size_t i = 0; i < this->endpoint_count_; ++i)
{
// compare the port and sin_addr (numeric host address)
if (profile->object_addr () == this->addrs_[i])
@@ -214,14 +214,14 @@ TAO_IIOP_Acceptor::open (TAO_ORB_Core *orb_core,
return -1;
- this->num_hosts_ = 1; // Only one hostname to store
+ this->endpoint_count_ = 1; // Only one hostname to store
ACE_NEW_RETURN (this->addrs_,
- ACE_INET_Addr[this->num_hosts_],
+ ACE_INET_Addr[this->endpoint_count_],
-1);
ACE_NEW_RETURN (this->hosts_,
- ACE_CString[this->num_hosts_],
+ ACE_CString[this->endpoint_count_],
-1);
if (this->hostname (orb_core,
@@ -239,6 +239,8 @@ TAO_IIOP_Acceptor::open (TAO_ORB_Core *orb_core,
int
TAO_IIOP_Acceptor::open_default (TAO_ORB_Core *orb_core,
+ int major,
+ int minor,
const char *options)
{
if (this->hosts_ != 0)
@@ -252,6 +254,12 @@ TAO_IIOP_Acceptor::open_default (TAO_ORB_Core *orb_core,
-1);
}
+ if (major >=0 && minor >= 0)
+ this->version_.set_version (ACE_static_cast (CORBA::Octet,
+ major),
+ ACE_static_cast (CORBA::Octet,
+ minor));
+
// Parse options
if (this->parse_options (options) == -1)
return -1;
@@ -327,12 +335,12 @@ TAO_IIOP_Acceptor::open_i (TAO_ORB_Core* orb_core,
// the same port. This is how a wildcard socket bind() is supposed
// to work.
u_short port = address.get_port_number ();
- for (size_t j = 0; j < this->num_hosts_; ++j)
+ for (size_t j = 0; j < this->endpoint_count_; ++j)
this->addrs_[j].set_port_number (port, 1);
if (TAO_debug_level > 5)
{
- for (size_t i = 0; i < this->num_hosts_; ++i)
+ for (size_t i = 0; i < this->endpoint_count_; ++i)
{
ACE_DEBUG ((LM_DEBUG,
ACE_TEXT ("\nTAO (%P|%t) IIOP_Acceptor::open_i - ")
@@ -426,16 +434,16 @@ TAO_IIOP_Acceptor::probe_interfaces (TAO_ORB_Core *orb_core)
// in the list of interfaces to query for a hostname, otherwise
// exclude it from the list.
if (if_cnt == lo_cnt)
- this->num_hosts_ = if_cnt;
+ this->endpoint_count_ = if_cnt;
else
- this->num_hosts_ = if_cnt - lo_cnt;
+ this->endpoint_count_ = if_cnt - lo_cnt;
ACE_NEW_RETURN (this->addrs_,
- ACE_INET_Addr[this->num_hosts_],
+ ACE_INET_Addr[this->endpoint_count_],
-1);
ACE_NEW_RETURN (this->hosts_,
- ACE_CString[this->num_hosts_],
+ ACE_CString[this->endpoint_count_],
-1);
// The number of hosts/interfaces we want to cache may not be the
@@ -470,7 +478,7 @@ TAO_IIOP_Acceptor::probe_interfaces (TAO_ORB_Core *orb_core)
CORBA::ULong
TAO_IIOP_Acceptor::endpoint_count (void)
{
- return this->num_hosts_;
+ return this->endpoint_count_;
}
int
@@ -479,7 +487,7 @@ TAO_IIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
{
// Create the decoding stream from the encapsulation in the buffer,
TAO_InputCDR cdr (profile.profile_data.mb ());
-
+
CORBA::Octet major, minor;
// Read the version. We just read it here. We don't*do any*
@@ -78,13 +78,13 @@ int
TAO_MProfile &mprofile)
{
- // Adding this->num_hosts_ to the TAO_MProfile.
+ // Adding this->endpoint_count_ to the TAO_MProfile.
int count = mprofile.profile_count ();